#
# spec file for package liquidshell
#
# Copyright (c) 2024 Martin Koller
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without released
Name:           liquidshell
Version:        1.10.0
Release:        1.2
Summary:        Basic Desktop Shell leveraging KDE Frameworks6 libraries
License:        GPL-3.0-or-later
URL:            https://apps.kde.org/liquidshell
Source0:        https://download.kde.org/stable/liquidshell/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/liquidshell/%{name}-%{version}.tar.xz.sig
Source2:        liquidshell.keyring
%endif
BuildRequires:  kf6-extra-cmake-modules
BuildRequires:  qt6-platformsupport-devel-static
BuildRequires:  cmake(KF6Archive)
BuildRequires:  cmake(KF6BluezQt)
BuildRequires:  cmake(KF6Config)
BuildRequires:  cmake(KF6ConfigWidgets)
BuildRequires:  cmake(KF6Crash)
BuildRequires:  cmake(KF6DBusAddons)
BuildRequires:  cmake(KF6DocTools)
BuildRequires:  cmake(KF6I18n)
BuildRequires:  cmake(KF6IconThemes)
BuildRequires:  cmake(KF6ItemViews)
BuildRequires:  cmake(KF6KCMUtils)
BuildRequires:  cmake(KF6KIO)
BuildRequires:  cmake(KF6NetworkManagerQt)
BuildRequires:  cmake(KF6NewStuff)
BuildRequires:  cmake(KF6Notifications)
BuildRequires:  cmake(KF6Service)
BuildRequires:  cmake(KF6Solid)
BuildRequires:  cmake(KF6StatusNotifierItem)
BuildRequires:  cmake(KF6WidgetsAddons)
BuildRequires:  cmake(KF6WindowSystem)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  cmake(packagekitqt6)
Requires:       kmenuedit6
Requires:       kscreen6
Requires:       plasma6-nm
Requires:       plasma6-workspace
Recommends:     bluedevil6
Recommends:     kwin6

%description
liquidshell is a basic Desktop Shell leveraging KDE Frameworks6 libraries.

%lang_package

%prep
%autosetup

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%find_lang %{name} %{name}.lang

%files lang -f %{name}.lang

%files
%doc README
%license COPYING
%{_datadir}/xsessions/liquidshell-session.desktop
%{_kf6_applicationsdir}/org.kde.liquidshell.desktop
%{_kf6_appstreamdir}/org.kde.liquidshell.appdata.xml
%{_kf6_bindir}/liquidshell
%{_kf6_bindir}/start_liquidshell
%{_kf6_iconsdir}/hicolor/48x48/apps/liquidshell.png
%{_kf6_notificationsdir}/liquidshell.notifyrc

%changelog
* Sat Oct  5 2024 Martin Koller <kollix@aon.at>
- Update to 1.10, which is the first version based on Qt6/KF6
* Fri Dec 15 2023 Christophe Marin <christophe@krop.fr>
- Require extra-cmake-modules at build time
* Sat Jul 29 2023 Martin Koller <kollix@aon.at>
- Update to 1.9
  * Added install options (sleep/shutdown after install)
  * Improved EULA handling on package installation
  * Added long format of time and date display to calendar popup
  * Create default folder for storing quicklaunch apps
  * SysLoad widget width depends on CPU count
  * Bugfixes and adjustments to newer KDE components
  * removed no longer needed include.patch
* Sun Jul 31 2022 Martin Koller <kollix@aon.at>
- Update to 1.8.1
  * Fix DBus menu labels/access key and icon search
  * Changes needed due to KCM renaming in KF5
  * allow focus on Desktop to fix issue with global shortcuts
  * close "please charge" notification immediately when plugged in
  * Send NotificationClosed dbus message on notification close
  * removed patch FindQt5ThemeSupport.patch now directly included
  * added include.patch which adds some missing includes and changes
    to make it compile on older openSuse versions
* Sun Dec 12 2021 Martin Koller <kollix@aon.at>
- Update to 1.8
  * Notifications show how long they remain open (small animation)
  * Weather Applet shows moon phase
  * Disk Usage Applet watches for mount/unmount to react quicker for update
  * Display improvements in software updates component
  * Added DBUS-Menu support (some apps don't provide own menu but only via DBUS, e.g. MS teams)
* Sun Nov  1 2020 Martin Koller <kollix@aon.at>
- Update to 1.7.2
  * port away from deprecated APIs
  * adapt to recent KDE changed name of bluetooth KCM
* Wed May 13 2020 Martin Koller <kollix@aon.at>
- Update to 1.7.1
  * correctly handle WPA2 and show secure before insecure APs
  * Avoid 100%% CPU when a window changes icon very often
  * OnScreenBrightness, MouseWheel on Pager to change desktops
* Wed May  6 2020 Martin Koller <kollix@aon.at>
- Update to 1.7
  * Also show non-primary batteries & charge-state in Device List
  * fix showing only removable devices in Device List
  * Allow to configure DiskUsageApplet bar text and background color
  * Arrange SysTray icons in an always compact way
  * also show battery in SysTray when charging
  * fix use of available screen geometry for multi-monitor setup
* Thu Feb 27 2020 Martin Koller <kollix@aon.at>
- Update to 1.6
  * provide a session desktop file to let the user chose liquidshell on login
  * auto-create network connection when selecting a new wifi network
  * avoid having to click twice when a new device needs to be mounted
  * use newer virtual desktop configuration module if available
  * show remaining packages during install
* Sat Jun  8 2019 kollix@aon.at
- Update to 1.5
  * Initial package
